@@ -1,4 +1,4 @@
-# $Id: REST.pm 24 2008-04-15 09:19:15Z dkrotkine $
+# $Id: REST.pm 27 2008-05-11 00:44:59Z dkrotkine $
 # RT::Client::REST
 #
 # Dmitri Tikhonov <dtikhonov@yahoo.com>
@@ -25,7 +25,7 @@ use strict;
 use warnings;
 
 use vars qw/$VERSION/;
-$VERSION = '0.35';
+$VERSION = '0.36';
 
 use Error qw(:try);
 use HTTP::Cookies;
@@ -480,7 +480,7 @@ sub _submit {
         # of an HTTP-like status line followed by optional header lines,
         # a blank line, and arbitrary text.
 
-        my ($head, $text) = split /\n\n/, $res->decoded_content, 2;
+        my ($head, $text) = split /\n\n/, $res->decoded_content(charset => 'none'), 2;
         my ($status, @headers) = split /\n/, $head;
         $text =~ s/\n*$/\n/ if ($text);
 
@@ -496,7 +496,7 @@ sub _submit {
         # not sufficiently portable and uncomplicated.)
         $res->code($1);
         $res->message($2);
-        $res->decoded_content($text);
+        $res->content($text);
         #$session->update($res) if ($res->is_success || $res->code != 401);
         if ($res->header('set-cookie')) {
             my $jar = HTTP::Cookies->new;
